<?php

namespace Drupal\flexible_descriptions;

/**
 * An interface for flexible descriptions helper service.
 */
interface FlexibleDescriptionsHelperInterface {

  /**
   * Gets a list of supported entity types.
   *
   * @return \Drupal\Core\Entity\EntityTypeInterface[]
   *   Array of entity types.
   */
  public function getSupportedEntityTypes(): array;

  /**
   * Generates and returns description identifier.
   *
   * @param string $entity_type_id
   *   ID of the entity type.
   * @param string $bundle_id
   *   ID of the bundle.
   * @param string $field_name
   *   Name of the field.
   *
   * @return string
   *   Description identifier string.
   */
  public function generateDescriptionIdentifier(
    string $entity_type_id,
    string $bundle_id,
    string $field_name): string;

  /**
   * Checks whether there is existing description and returns it.
   *
   * @param string $description_identifier
   *   Description identifier string.
   *
   * @return array|int
   *   Description ID value.
   */
  public function getExistingDescription(string $description_identifier): array|int;

  /**
   * Get an array of parent keys of the '#description' item.
   *
   * @param array $field_widget_complete_form
   *   Form widget array.
   *
   * @return null|array
   *   NULL|array of '#description' parent keys.
   */
  public function getFieldWidgetDescriptionParents(array $field_widget_complete_form): ?array;

  /**
   * Get the description text by specified identifier.
   *
   * @param string $description_identifier
   *   Description identifier string.
   *
   * @return string
   *   Returns flexible description text string.
   */
  public function getFlexibleDescriptionText(string $description_identifier): string;

}
